@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito;
 BEGIN {
-  $Mojito::VERSION = '0.04';
+  $Mojito::VERSION = '0.05';
 }
 use Moo;
 
@@ -25,7 +25,8 @@ has bench_fixture => ( is => 'ro', lazy => 1, builder => '_build_bench_fixture')
 
 =head2 create_page
 
-Create a new page and return its id (as a string, not an object).
+Create a new page and return the url to redirect to, namely the page in edit mode.
+We might change this to view mode if demand persuades. 
 
 =cut
 
@@ -40,8 +41,8 @@ sub create_page {
     $page_struct->{body_html} = $self->render_body($page_struct);
     $page_struct->{title}     = $self->intro_text( $page_struct->{body_html} );
     my $id = $self->create($page_struct);
-
-    return $id;
+    
+    return $self->base_url . 'page/' . $id . '/edit';
 }
 
 =head2 preview_page
@@ -99,7 +100,7 @@ sub update_page {
     # Save page
     $self->update( $params->{id}, $page );
 
-    return $page;
+    return $self->base_url . 'page/' . $params->{id};
 }
 
 =head2 edit_page_form
@@ -130,7 +131,7 @@ sub view_page {
 
     my $page          = $self->read( $params->{id} );
     my $rendered_page = $self->render_page($page);
-    my $links         = $self->get_most_recent_links( 0, $self->base_url );
+    my $links         = $self->get_most_recent_links;
 
     # Change class on view_area when we're in view mode.
     $rendered_page =~
@@ -141,6 +142,35 @@ sub view_page {
     return $rendered_page;
 }
 
+=head2 view_home_page
+
+Create the view for the base of the application.
+
+=cut
+
+sub view_home_page {
+    my $self = shift;
+
+    my $output = $self->home_page;
+    my $links  = $self->get_most_recent_links;
+    $output =~ s/(<section\s+id="recent_area".*?>)<\/section>/$1${links}<\/section>/si;
+    
+    return $output;
+}
+
+=head2 delete_page
+
+Delet a page given a page id.
+Return the URL to recent (maybe home someday?)
+
+=cut
+
+sub delete_page {
+    my ( $self, $params ) = @_;
+    $self->delete($params->{id});
+    return $self->base_url . 'recent';
+}
+
 =head2 bench
 
 A path for benchmarking to get an basic idea of peformance.
