@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Page::CRUD;
 BEGIN {
-  $Mojito::Page::CRUD::VERSION = '0.04';
+  $Mojito::Page::CRUD::VERSION = '0.05';
 }
 use MongoDB::OID;
 use 5.010;
@@ -135,19 +135,20 @@ sub get_most_recent_link_data {
 =head2 get_most_recent_links
 
 Turn the data into HTML
+$args should be a HashRef of options
 
 =cut
 
 sub get_most_recent_links {
-    my ($self, $want_delete_link) = @_;
+    my ($self, $args) = @_;
     
     my $base_url = $self->base_url;
     
     my $link_data = $self->get_most_recent_link_data;
-    my $links = '<b>Recent Articles</b><br />';
+    my $links = '<span id="recent_articles_label" style="font-weight: bold;">Recent Articles</span><br />';
     foreach my $datum (@{$link_data}) {
         $links .= "<a href=\"${base_url}page/" . $datum->{id} . '">' . $datum->{title} . "</a>";
-        if ($want_delete_link) {
+        if ($args->{want_delete_link}) {
             $links .=  " | <a id=\"page_delete\" href=\"${base_url}page/"   . $datum->{id} . '/delete"> delete</a>';
         }
         $links .= "<br />\n";
